@@ -14,7 +14,7 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.0.15'
+__version__ = '0.1.0'
 
 from importlib import import_module
 from mock import Mock, patch
@@ -60,6 +60,13 @@ class UnitTests(TestCase):
         pass
 
 
+class FluentAnyArguments(object):
+    pass
+
+
+ANY_ARGUMENTS = FluentAnyArguments()
+
+
 class FluentTargeting(object):
 
     def __init__(self, target):
@@ -160,6 +167,8 @@ class FluentMock(FluentTargeting):
         for answer in self._answers:
             if answer.arguments == arguments:
                 return answer.next()
+            if answer.arguments and answer.arguments[0] == ANY_ARGUMENTS:
+                return answer.next()
 
         return None
 
